==> hlint-2.0.9-13-armv7h.pkg.tar.xz: usr/share/haskell/register/hlint.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hlint
version: 2.0.9
id: hlint-2.0.9-JYQFv3otGGgEx8V6fcr81u
key: hlint-2.0.9-JYQFv3otGGgEx8V6fcr81u
license: BSD3
copyright: Neil Mitchell 2006-2017
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/hlint#readme
synopsis: Source code suggestions
description:
    HLint gives suggestions on how to improve your source code.
category: Development
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
exposed-modules:
    Language.Haskell.HLint Language.Haskell.HLint3
hidden-modules: Paths_hlint Apply CmdLine Grep HLint HsColour Idea
                Report Util Parallel Refact Config.All Config.Compute
                Config.Haskell Config.Type Config.Yaml HSE.All HSE.Bracket
                HSE.FreeVars HSE.Match HSE.Reduce HSE.Scope HSE.Type HSE.Util
                Hint.All Hint.Bracket Hint.Comment Hint.Duplicate Hint.Export
                Hint.Extensions Hint.Import Hint.Lambda Hint.List Hint.ListRec
                Hint.Match Hint.Monad Hint.Naming Hint.NewType Hint.Pattern
                Hint.Pragma Hint.Restrict Hint.Type Hint.Unsafe Hint.Util Test.All
                Test.Annotations Test.InputOutput Test.Proof Test.Translate
                Test.Util
abi: 7bc2709316cc1c4242c7bf4e49759c87
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/hlint-2.0.9
library-dirs: /usr/lib/ghc-8.0.2/site-local/hlint-2.0.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hlint
hs-libraries: HShlint-2.0.9-JYQFv3otGGgEx8V6fcr81u
depends:
    ansi-terminal-0.6.3.1-59sjf9WqHYuFAo9gQw9Bhp base-4.9.1.0
    bytestring-0.10.8.1 cmdargs-0.10.17-gTr0lzwrHbBcQQ47pfTGo
    containers-0.5.7.1 cpphs-1.20.8-GyXkmDRyCCk1Z2EfyxKuOh
    directory-1.3.0.0 extra-1.5.3-D0CTSfwIrg4DdcYZmgSnz1
    filepath-1.4.1.1 haskell-src-exts-1.19.1-7Ymk4sexwB7KzlRpbPSyAR
    hscolour-1.24.1-8bO2w1mmWhpHwQRVjkjSBA process-1.4.3.0
    refact-0.3.0.2-1GDOx77emyrIkqpPHv9P18
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq transformers-0.5.2.0
    uniplate-1.6.12-A02jTsyQmCWKBCl3BhcKvP
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
    yaml-0.8.23.3-Zl0UWmB8DzHSZcW3qkjNP
haddock-interfaces: /usr/share/doc/hlint/html/hlint.haddock
haddock-html: /usr/share/doc/hlint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hlint-2.0.9-14-armv7h.pkg.tar.xz: usr/share/haskell/register/hlint.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hlint
version: 2.0.9
id: hlint-2.0.9-FodmbHooZJbH31WHuyB6yh
key: hlint-2.0.9-FodmbHooZJbH31WHuyB6yh
license: BSD3
copyright: Neil Mitchell 2006-2017
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/hlint#readme
synopsis: Source code suggestions
description:
    HLint gives suggestions on how to improve your source code.
category: Development
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
exposed-modules:
    Language.Haskell.HLint Language.Haskell.HLint3
hidden-modules: Paths_hlint Apply CmdLine Grep HLint HsColour Idea
                Report Util Parallel Refact Config.All Config.Compute
                Config.Haskell Config.Type Config.Yaml HSE.All HSE.Bracket
                HSE.FreeVars HSE.Match HSE.Reduce HSE.Scope HSE.Type HSE.Util
                Hint.All Hint.Bracket Hint.Comment Hint.Duplicate Hint.Export
                Hint.Extensions Hint.Import Hint.Lambda Hint.List Hint.ListRec
                Hint.Match Hint.Monad Hint.Naming Hint.NewType Hint.Pattern
                Hint.Pragma Hint.Restrict Hint.Type Hint.Unsafe Hint.Util Test.All
                Test.Annotations Test.InputOutput Test.Proof Test.Translate
                Test.Util
abi: 376ba32d78329f6d8e2636206146d44d
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/hlint-2.0.9
library-dirs: /usr/lib/ghc-8.0.2/site-local/hlint-2.0.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hlint
hs-libraries: HShlint-2.0.9-FodmbHooZJbH31WHuyB6yh
depends:
    ansi-terminal-0.6.3.1-59sjf9WqHYuFAo9gQw9Bhp base-4.9.1.0
    bytestring-0.10.8.1 cmdargs-0.10.17-gTr0lzwrHbBcQQ47pfTGo
    containers-0.5.7.1 cpphs-1.20.8-GyXkmDRyCCk1Z2EfyxKuOh
    directory-1.3.0.0 extra-1.5.3-D0CTSfwIrg4DdcYZmgSnz1
    filepath-1.4.1.1 haskell-src-exts-1.19.1-7Ymk4sexwB7KzlRpbPSyAR
    hscolour-1.24.1-8bO2w1mmWhpHwQRVjkjSBA process-1.4.3.0
    refact-0.3.0.2-1GDOx77emyrIkqpPHv9P18
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq transformers-0.5.2.0
    uniplate-1.6.12-A02jTsyQmCWKBCl3BhcKvP
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
    yaml-0.8.23.3-A4Z2dpSnsa68VwAvl4MRME
haddock-interfaces: /usr/share/doc/hlint/html/hlint.haddock
haddock-html: /usr/share/doc/hlint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
